@@ -1,4 +1,4 @@
-function res = test_precision_divide(args)
+function res = precision_divide(args)
 % This function devides val1 by val2 and returns the result
     res = args.val1 / args.val2;
 
