@@ -1,4 +1,4 @@
-function res = test_precision_multiply(args)
+function res = precision_multiply(args)
 % This function returns the product of two arguments val1 and val2
     res = args.val1 * args.val2;
 
